@@ -30,15 +30,11 @@ namespace
 {
 
 using v8::Array;
-using v8::Boolean;
-using v8::FunctionTemplate;
 using v8::Integer;
 using v8::Local;
-using v8::Null;
 using v8::Object;
 using v8::ObjectTemplate;
 using v8::String;
-using v8::Value;
 
 
 struct Iconv
@@ -66,12 +62,12 @@ struct Iconv
     Local<ObjectTemplate> t = Nan::New<ObjectTemplate>();
     t->SetInternalFieldCount(1);
     object_template.Reset(t);
-    obj->Set(Nan::New<String>("make").ToLocalChecked(),
-             Nan::New<FunctionTemplate>(Make)->GetFunction());
-    obj->Set(Nan::New<String>("convert").ToLocalChecked(),
-             Nan::New<FunctionTemplate>(Convert)->GetFunction());
-#define EXPORT_ERRNO(err) \
-    obj->Set(Nan::New<String>(#err).ToLocalChecked(), Nan::New<Integer>(err))
+    Nan::SetMethod(obj, "make", Make);
+    Nan::SetMethod(obj, "convert", Convert);
+#define EXPORT_ERRNO(err)                                                     \
+    Nan::Set(obj,                                                             \
+             Nan::New<String>(#err).ToLocalChecked(),                         \
+             Nan::New<Integer>(err))
     EXPORT_ERRNO(EINVAL);
     EXPORT_ERRNO(EILSEQ);
     EXPORT_ERRNO(E2BIG);
@@ -88,7 +84,8 @@ struct Iconv
     }
     Iconv* iv = new Iconv(conv);
     Local<Object> obj =
-        Nan::New<ObjectTemplate>(object_template)->NewInstance();
+        Nan::NewInstance(Nan::New<ObjectTemplate>(object_template))
+        .ToLocalChecked();
     Nan::SetInternalFieldPointer(obj, 0, iv);
     Nan::Persistent<Object> persistent(obj);
     persistent.SetWeak(iv, WeakCallback, Nan::WeakCallbackType::kParameter);
@@ -123,8 +120,8 @@ struct Iconv
     }
     input_consumed -= input_size;
     output_consumed -= output_size;
-    rc->Set(0, Nan::New<Integer>(static_cast<uint32_t>(input_consumed)));
-    rc->Set(1, Nan::New<Integer>(static_cast<uint32_t>(output_consumed)));
+    Nan::Set(rc, 0, Nan::New<Integer>(static_cast<uint32_t>(input_consumed)));
+    Nan::Set(rc, 1, Nan::New<Integer>(static_cast<uint32_t>(output_consumed)));
     info.GetReturnValue().Set(errorno);
   }
 
